@@ -175,6 +175,12 @@ class TemplateMiddleware(object):
         xslt = self.get(xslt)
         proc.appendStylesheet(xslt)
         out = proc.run(xml, topLevelParams=params)
+        content_type = str(proc.outputParams.mediaType)
+        if content_type:
+            for index, header in enumerate(self.headers):
+                if header[0].lower() == 'content-type':
+                    break
+            self.headers[index] = ('Content-Type', content_type)
         del proc
         return out
 
